Skip to main content Module abi Copy item path Source FlatTypes WasmSignature A core WebAssembly signature with params and results. AbiVariant We use a different ABI for wasm importing functions exported by the host
than for wasm exporting functions imported by the host. Bitcast Instruction LiftLower Whether the glue code surrounding a call is lifting arguments and lowering
results or vice versa. Realloc WasmType Enumerates wasm types used by interface types when lowering/lifting. Bindgen Trait for language implementors to use to generate glue code between native
WebAssembly signatures and interface types signatures. call Generates an abstract sequence of instructions which represents this
function being adapted as an imported function. cast Returns the Bitcast required to move a value of flat type
from into flat type to under the canonical ABI’s unification
rules. Panics if the pair isn’t a legal bitcast per the spec. deallocate_lists_and_own_in_types Generate instructions in bindgen to deallocate all lists in ptr where
that’s a pointer to a sequence of types stored in linear memory. deallocate_lists_in_types Generate instructions in bindgen to deallocate all lists in ptr where
that’s a pointer to a sequence of types stored in linear memory. flat_types Flatten a component-level type into its canonical-ABI wasm-type
sequence, or return None if the result would exceed max_params. guest_export_needs_post_return Returns whether the Function specified needs a post-return function to
be generated in guest code. guest_export_params_have_allocations lift_from_memory lower_flat lower_to_memory post_return Used in a similar manner as the Interface::call function except is
used to generate the post-return callback for func.