pub fn cast(from: WasmType, to: WasmType) -> BitcastExpand description
Returns the Bitcast required to move a value of flat type
from into flat type to under the canonical ABI’s unification
rules. Panics if the pair isn’t a legal bitcast per the spec.